@@ -1,5 +1,5 @@
 
-# Copyright: Rob Zel, License: BSD-3-Clause
+# Copyright: The TWPY Organization, License: BSD-3-Clause
 
 import webview
 # from threading import Thread
@@ -14,7 +14,7 @@ def printif(cond, str):
         print(str)
 
 
-def safesavestr(path, tmp_path, data, verbose):
+def safesavestr(path, tmp_path, data, verbose): # Failproof Save by RZ
     printif(verbose, "failproof_save: writing temp to path: " + tmp_path)
     f = open(tmp_path, "wb")
     f.write(bytes(data, 'UTF-8'))
